@@ -126,12 +126,12 @@ const BREAK_CONSTRAINT_CODE: i32 = 5;
 const SKILL_CONSTRAINT_CODE: i32 = 6;
 const LOCKING_CONSTRAINT_CODE: i32 = 7;
 const REACHABLE_CONSTRAINT_CODE: i32 = 8;
-const PRIORITY_CONSTRAINT_CODE: i32 = 9;
-const AREA_CONSTRAINT_CODE: i32 = 10;
-const DISPATCH_CONSTRAINT_CODE: i32 = 11;
-const TOUR_SIZE_CONSTRAINT_CODE: i32 = 12;
-const TOUR_ORDER_CONSTRAINT_CODE: i32 = 13;
-const GROUP_CONSTRAINT_CODE: i32 = 14;
+const AREA_CONSTRAINT_CODE: i32 = 9;
+const DISPATCH_CONSTRAINT_CODE: i32 = 10;
+const TOUR_SIZE_CONSTRAINT_CODE: i32 = 11;
+const TOUR_ORDER_CONSTRAINT_CODE: i32 = 12;
+const GROUP_CONSTRAINT_CODE: i32 = 13;
+const COMPATIBILITY_CONSTRAINT_CODE: i32 = 14;
 
 pub(crate) const UNASSIGNABLE_ROUTE_KEY: i32 = 100;
 
