@@ -19,6 +19,7 @@ use std::cmp::Ordering;
 const MULTI_JOB_SAMPLE_SIZE: usize = 3;
 
 type PlaceData = (Option<Location>, Duration, Vec<TimeSpan>, Option<String>);
+type ApiJob = crate::format::problem::Job;
 
 pub(crate) fn read_jobs_with_extra_locks(
     api_problem: &ApiProblem,
@@ -161,9 +162,9 @@ fn read_required_jobs(
 
         let problem_job = if singles.len() > 1 {
             let deliveries_start_index = job.pickups.as_ref().map_or(0, |p| p.len());
-            get_multi_job(&job.id, &job.skills, job.value, &job.group, singles, deliveries_start_index, random)
+            get_multi_job(job, singles, deliveries_start_index, random)
         } else {
-            get_single_job(&job.id, singles.into_iter().next().unwrap(), &job.skills, job.value, &job.group)
+            get_single_job(job, singles.into_iter().next().unwrap())
         };
 
         job_index.insert(job.id.clone(), problem_job.clone());
@@ -402,37 +403,30 @@ fn get_single_with_extras(
     single
 }
 
-fn get_single_job(
-    id: &str,
-    single: Single,
-    skills: &Option<FormatJobSkills>,
-    value: Option<f64>,
-    group: &Option<String>,
-) -> Job {
+fn get_single_job(job: &ApiJob, single: Single) -> Job {
     let mut single = single;
-    single.dimens.set_id(id);
+    single.dimens.set_id(&job.id);
 
-    add_value(&mut single.dimens, value);
-    add_group(&mut single.dimens, group);
-    add_job_skills(&mut single.dimens, skills);
+    add_value(&mut single.dimens, &job.value);
+    add_group(&mut single.dimens, &job.group);
+    add_compatibility(&mut single.dimens, &job.compatibility);
+    add_job_skills(&mut single.dimens, &job.skills);
 
     Job::Single(Arc::new(single))
 }
 
 fn get_multi_job(
-    id: &str,
-    skills: &Option<FormatJobSkills>,
-    value: Option<f64>,
-    group: &Option<String>,
+    job: &ApiJob,
     singles: Vec<Single>,
     deliveries_start_index: usize,
     random: &Arc<dyn Random + Send + Sync>,
 ) -> Job {
     let mut dimens: Dimensions = Default::default();
-    dimens.set_id(id);
-    add_value(&mut dimens, value);
-    add_group(&mut dimens, group);
-    add_job_skills(&mut dimens, skills);
+    dimens.set_id(&job.id);
+    add_value(&mut dimens, &job.value);
+    add_group(&mut dimens, &job.group);
+    add_compatibility(&mut dimens, &job.compatibility);
+    add_job_skills(&mut dimens, &job.skills);
 
     let singles = singles.into_iter().map(Arc::new).collect::<Vec<_>>();
 
@@ -474,8 +468,8 @@ fn add_order(dimens: &mut Dimensions, order: &Option<i32>) {
     }
 }
 
-fn add_value(dimens: &mut Dimensions, value: Option<f64>) {
-    if let Some(value) = value {
+fn add_value(dimens: &mut Dimensions, value: &Option<f64>) {
+    if let Some(value) = *value {
         dimens.set_value("value", value);
     }
 }
@@ -486,6 +480,12 @@ fn add_group(dimens: &mut Dimensions, group: &Option<String>) {
     }
 }
 
+fn add_compatibility(dimens: &mut Dimensions, compatibility: &Option<String>) {
+    if let Some(compatibility) = compatibility {
+        dimens.set_value("compat", compatibility.clone());
+    }
+}
+
 fn add_job_skills(dimens: &mut Dimensions, skills: &Option<FormatJobSkills>) {
     if let Some(skills) = skills {
         dimens.set_value(
