@@ -118,6 +118,7 @@ pub struct ProblemProperties {
     has_reloads: bool,
     has_order: bool,
     has_group: bool,
+    has_compatibility: bool,
     has_area_limits: bool,
     has_tour_size_limits: bool,
     max_job_value: Option<f64>,
@@ -219,14 +220,16 @@ fn map_to_problem(
     let objective = create_objective(&api_problem, &mut constraint, &problem_props);
     let constraint = Arc::new(constraint);
     let extras = Arc::new(
-        create_extras(&api_problem, constraint.clone(), &problem_props, job_index, coord_index).map_err(|err| {
-            // TODO make sure that error matches actual reason
-            vec![FormatError::new(
-                "E0002".to_string(),
-                "cannot create transport costs".to_string(),
-                format!("check clustering config: '{}'", err),
-            )]
-        })?,
+        create_extras(&api_problem, constraint.clone(), random, &problem_props, job_index, coord_index).map_err(
+            |err| {
+                // TODO make sure that error matches actual reason
+                vec![FormatError::new(
+                    "E0002".to_string(),
+                    "cannot create transport costs".to_string(),
+                    format!("check clustering config: '{}'", err),
+                )]
+            },
+        )?,
     );
 
     Ok(Problem {
@@ -273,6 +276,10 @@ fn create_constraint_pipeline(
         constraint.add_module(Arc::new(BreakModule::new(transport.clone(), BREAK_CONSTRAINT_CODE)));
     }
 
+    if props.has_compatibility {
+        constraint.add_module(Arc::new(CompatibilityModule::new(COMPATIBILITY_CONSTRAINT_CODE, COMPATIBILITY_KEY)));
+    }
+
     if props.has_group {
         constraint.add_module(Arc::new(GroupModule::new(jobs.size(), GROUP_CONSTRAINT_CODE, GROUP_KEY)));
     }
@@ -349,6 +356,7 @@ fn add_tour_size_module(constraint: &mut ConstraintPipeline) {
 fn create_extras(
     api_problem: &ApiProblem,
     constraint: Arc<ConstraintPipeline>,
+    random: Arc<dyn Random + Send + Sync>,
     props: &ProblemProperties,
     job_index: JobIndex,
     coord_index: Arc<CoordIndex>,
@@ -362,7 +370,7 @@ fn create_extras(
     extras.insert("job_index".to_owned(), Arc::new(job_index.clone()));
 
     if props.has_dispatch {
-        extras.insert("route_modifier".to_owned(), Arc::new(get_route_modifier(constraint, job_index)));
+        extras.insert("route_modifier".to_owned(), Arc::new(get_route_modifier(constraint, random, job_index)));
     }
 
     if let Some(config) = create_cluster_config(api_problem)? {
@@ -423,6 +431,7 @@ fn get_problem_properties(api_problem: &ApiProblem, matrices: &[Matrix]) -> Prob
         .any(|order| order > 0);
 
     let has_group = api_problem.plan.jobs.iter().any(|job| job.group.is_some());
+    let has_compatibility = api_problem.plan.jobs.iter().any(|job| job.compatibility.is_some());
 
     let has_area_limits = api_problem
         .fleet
@@ -441,6 +450,7 @@ fn get_problem_properties(api_problem: &ApiProblem, matrices: &[Matrix]) -> Prob
         has_reloads,
         has_order,
         has_group,
+        has_compatibility,
         has_area_limits,
         has_tour_size_limits,
         max_job_value,
