@@ -14,6 +14,7 @@ use vrp_core::models::common::*;
 use vrp_core::models::problem::Multi;
 use vrp_core::models::solution::{Activity, Route};
 use vrp_core::models::{Problem, Solution};
+use vrp_core::solver::processing::VicinityDimension;
 use vrp_core::solver::Metrics;
 
 type ApiActivity = crate::format::solution::model::Activity;
@@ -107,9 +108,12 @@ pub fn create_solution(problem: &Problem, solution: &Solution, metrics: Option<&
 
 fn create_tour(problem: &Problem, route: &Route, coord_index: &CoordIndex) -> Tour {
     let is_multi_dimen = has_multi_dimensional_capacity(problem.extras.as_ref());
+    let parking = get_parking_time(problem.extras.as_ref());
 
     let actor = route.actor.as_ref();
     let vehicle = actor.vehicle.as_ref();
+    let profile = &vehicle.profile;
+    let transport = problem.transport.as_ref();
 
     let mut tour = Tour {
         vehicle_id: vehicle.dimens.get_id().unwrap().clone(),
@@ -123,7 +127,7 @@ fn create_tour(problem: &Problem, route: &Route, coord_index: &CoordIndex) -> To
 
     let mut leg = intervals.into_iter().fold(Leg::empty(), |leg, (start_idx, end_idx)| {
         let (start_delivery, end_pickup) = route.tour.activities_slice(start_idx, end_idx).iter().fold(
-            (leg.load.unwrap_or_else(MultiDimLoad::default), MultiDimLoad::default()),
+            (leg.load.unwrap_or_default(), MultiDimLoad::default()),
             |acc, activity| {
                 let (delivery, pickup) = activity
                     .job
@@ -165,7 +169,9 @@ fn create_tour(problem: &Problem, route: &Route, coord_index: &CoordIndex) -> To
                         None
                     },
                     job_tag: None,
+                    commute: None,
                 }],
+                parking: None,
             });
             (start_idx + 1, start)
         } else {
@@ -201,30 +207,61 @@ fn create_tour(problem: &Problem, route: &Route, coord_index: &CoordIndex) -> To
                     _ => activity_type.clone(),
                 };
 
-                let driving =
-                    problem.transport.duration(&vehicle.profile, prev_location, act.place.location, prev_departure);
-                let arrival = prev_departure + driving;
-                let start = act.schedule.arrival.max(act.place.time.start);
-                let waiting = start - act.schedule.arrival;
-                let serving = act.place.duration;
-                let departure = start + serving;
+                let commute = act.commute.clone().unwrap_or_default();
+                let commuting = commute.duration();
 
-                // total cost and distance
-                let cost = leg.statistic.cost
-                    + problem.activity.cost(actor, act, act.schedule.arrival)
-                    + problem.transport.cost(actor, prev_location, act.place.location, prev_departure);
-                let distance = leg.statistic.distance
-                    + problem.transport.distance(&vehicle.profile, prev_location, act.place.location, prev_departure)
-                        as i64;
+                let (driving, transport_cost) = if commute.is_zero_distance() {
+                    // NOTE: use original cost traits to adapt time-based costs (except waiting/commuting)
+                    let duration = transport.duration(profile, prev_location, act.place.location, prev_departure);
+                    let transport_cost = transport.cost(actor, prev_location, act.place.location, prev_departure);
+                    (duration, transport_cost)
+                } else {
+                    // NOTE: no need to drive in case of non-zero commute, this goes to commuting time
+                    (0., commuting * vehicle.costs.per_service_time)
+                };
 
-                let is_new_location = prev_location != act.place.location;
+                // NOTE two clusters at the same stop location
+                let parking =
+                    match (prev_location == act.place.location, act.commute.is_some(), commute.is_zero_distance()) {
+                        (false, true, true) => parking,
+                        _ => 0.,
+                    };
 
-                if is_new_location {
+                let activity_arrival = parking + act.schedule.arrival + commute.forward.duration;
+                let service_start = activity_arrival.max(act.place.time.start);
+                let waiting = service_start - activity_arrival;
+                let serving = act.place.duration - parking;
+                let service_end = service_start + serving;
+                let activity_departure = service_end;
+
+                // TODO: add better support of time based activity costs
+                let serving_cost = problem.activity.cost(actor, act, service_start);
+                let total_cost = serving_cost + transport_cost + waiting * vehicle.costs.per_waiting_time;
+
+                let location_distance =
+                    transport.distance(profile, prev_location, act.place.location, prev_departure) as i64;
+                let distance = leg.statistic.distance + location_distance - commute.forward.distance as i64;
+
+                let is_new_stop = match (act.commute.as_ref(), prev_location == act.place.location) {
+                    (Some(commute), false) if commute.is_zero_distance() => true,
+                    (Some(_), _) => false,
+                    (None, is_same_location) => !is_same_location,
+                };
+
+                if is_new_stop {
                     tour.stops.push(Stop {
                         location: coord_index.get_by_idx(act.place.location).unwrap(),
-                        time: format_as_schedule(&(arrival, departure)),
+                        time: format_schedule(&act.schedule),
                         load: prev_load.as_vec(),
                         distance,
+                        parking: if parking > 0. {
+                            Some(Interval {
+                                start: format_time(act.schedule.arrival),
+                                end: format_time(act.schedule.arrival + parking),
+                            })
+                        } else {
+                            None
+                        },
                         activities: vec![],
                     });
                 }
@@ -234,31 +271,47 @@ fn create_tour(problem: &Problem, route: &Route, coord_index: &CoordIndex) -> To
                 let last = tour.stops.len() - 1;
                 let mut last = tour.stops.get_mut(last).unwrap();
 
-                last.time.departure = format_time(departure);
+                last.time.departure = format_time(act.schedule.departure);
                 last.load = load.as_vec();
                 last.activities.push(ApiActivity {
                     job_id,
                     activity_type: activity_type.clone(),
-                    location: if !is_new_location && activity_type == "dispatch" {
+                    location: if !is_new_stop && activity_type == "dispatch" {
                         None
                     } else {
                         Some(coord_index.get_by_idx(act.place.location).unwrap())
                     },
-                    time: Some(Interval { start: format_time(arrival), end: format_time(departure) }),
+                    time: Some(Interval { start: format_time(activity_arrival), end: format_time(activity_departure) }),
                     job_tag,
+                    commute: act
+                        .commute
+                        .as_ref()
+                        .map(|commute| Commute::new(commute, act.schedule.arrival, activity_departure, coord_index)),
                 });
 
+                // NOTE detect when vehicle returns after activity to stop point
+                let end_location = if commute.backward.is_zero_distance() {
+                    act.place.location
+                } else {
+                    tour.stops
+                        .last()
+                        .and_then(|stop| coord_index.get_by_loc(&stop.location))
+                        .expect("expect to have at least one stop")
+                };
+
                 Leg {
-                    last_detail: Some((act.place.location, act.schedule.departure)),
+                    last_detail: Some((end_location, act.schedule.departure)),
                     statistic: Statistic {
-                        cost,
+                        cost: leg.statistic.cost + total_cost,
                         distance,
-                        duration: leg.statistic.duration + departure as i64 - prev_departure as i64,
+                        duration: leg.statistic.duration + act.schedule.departure as i64 - prev_departure as i64,
                         times: Timing {
                             driving: leg.statistic.times.driving + driving as i64,
                             serving: leg.statistic.times.serving + (if is_break { 0 } else { serving as i64 }),
                             waiting: leg.statistic.times.waiting + waiting as i64,
                             break_time: leg.statistic.times.break_time + (if is_break { serving as i64 } else { 0 }),
+                            commuting: leg.statistic.times.commuting + commuting as i64,
+                            parking: leg.statistic.times.parking + parking as i64,
                         },
                     },
                     load: Some(load),
@@ -294,10 +347,6 @@ fn format_schedule(schedule: &DomainSchedule) -> ApiSchedule {
     ApiSchedule { arrival: format_time(schedule.arrival), departure: format_time(schedule.departure) }
 }
 
-fn format_as_schedule(schedule: &(f64, f64)) -> ApiSchedule {
-    format_schedule(&DomainSchedule::new(schedule.0, schedule.1))
-}
-
 fn calculate_load(current: MultiDimLoad, act: &Activity, is_multi_dimen: bool) -> MultiDimLoad {
     let job = act.job.as_ref();
     let demand = job.and_then(|job| get_capacity(&job.dimens, is_multi_dimen)).unwrap_or_default();
@@ -378,6 +427,10 @@ fn has_multi_dimensional_capacity(extras: &DomainExtras) -> bool {
     }
 }
 
+fn get_parking_time(extras: &DomainExtras) -> f64 {
+    extras.get_cluster_config().map_or(0., |config| config.serving.get_parking())
+}
+
 fn create_extras(_solution: &Solution, metrics: Option<&Metrics>) -> Option<Extras> {
     metrics.map(|metrics| Extras {
         metrics: Some(ApiMetrics {
