@@ -15,7 +15,7 @@ fn can_use_init_solution_with_dispatch() {
                 create_delivery_job("job1", vec![1., 0.]),
                 create_delivery_job_with_times("job2", vec![1., 0.], vec![(7, 100)], 1.),
             ],
-            relations: None,
+            ..create_empty_plan()
         },
         fleet: Fleet {
             vehicles: vec![VehicleType {
@@ -43,7 +43,7 @@ fn can_use_init_solution_with_dispatch() {
             cost: 34.,
             distance: 4,
             duration: 10,
-            times: Timing { driving: 4, serving: 6, waiting: 0, break_time: 0 },
+            times: Timing { driving: 4, serving: 6, ..Timing::default() },
         },
         tours: vec![
             Tour {
@@ -58,6 +58,7 @@ fn can_use_init_solution_with_dispatch() {
                             departure: "1970-01-01T00:00:04Z".to_string(),
                         },
                         distance: 0,
+                        parking: None,
                         load: vec![1],
                         activities: vec![
                             Activity {
@@ -69,6 +70,7 @@ fn can_use_init_solution_with_dispatch() {
                                     end: "1970-01-01T00:00:02Z".to_string(),
                                 }),
                                 job_tag: None,
+                                commute: None,
                             },
                             Activity {
                                 job_id: "dispatch".to_string(),
@@ -79,6 +81,7 @@ fn can_use_init_solution_with_dispatch() {
                                     end: "1970-01-01T00:00:04Z".to_string(),
                                 }),
                                 job_tag: None,
+                                commute: None,
                             },
                         ],
                     },
@@ -103,7 +106,7 @@ fn can_use_init_solution_with_dispatch() {
                     cost: 17.,
                     distance: 2,
                     duration: 5,
-                    times: Timing { driving: 2, serving: 3, waiting: 0, break_time: 0 },
+                    times: Timing { driving: 2, serving: 3, ..Timing::default() },
                 },
             },
             Tour {
@@ -118,6 +121,7 @@ fn can_use_init_solution_with_dispatch() {
                             departure: "1970-01-01T00:00:06Z".to_string(),
                         },
                         distance: 0,
+                        parking: None,
                         load: vec![1],
                         activities: vec![
                             Activity {
@@ -129,6 +133,7 @@ fn can_use_init_solution_with_dispatch() {
                                     end: "1970-01-01T00:00:04Z".to_string(),
                                 }),
                                 job_tag: None,
+                                commute: None,
                             },
                             Activity {
                                 job_id: "dispatch".to_string(),
@@ -139,6 +144,7 @@ fn can_use_init_solution_with_dispatch() {
                                     end: "1970-01-01T00:00:06Z".to_string(),
                                 }),
                                 job_tag: None,
+                                commute: None,
                             },
                         ],
                     },
@@ -163,7 +169,7 @@ fn can_use_init_solution_with_dispatch() {
                     cost: 17.,
                     distance: 2,
                     duration: 5,
-                    times: Timing { driving: 2, serving: 3, waiting: 0, break_time: 0 },
+                    times: Timing { driving: 2, serving: 3, ..Timing::default() },
                 },
             },
         ],
