@@ -5,7 +5,7 @@ use crate::helpers::*;
 #[test]
 fn can_use_vehicle_with_open_end() {
     let problem = Problem {
-        plan: Plan { jobs: vec![create_delivery_job("job1", vec![1., 0.])], relations: Option::None },
+        plan: Plan { jobs: vec![create_delivery_job("job1", vec![1., 0.])], ..create_empty_plan() },
         fleet: Fleet { vehicles: vec![create_default_vehicle_type()], profiles: create_default_matrix_profiles() },
         ..create_empty_problem()
     };
@@ -26,7 +26,7 @@ fn can_use_vehicle_with_open_end() {
                 cost: 0.,
                 distance: 0,
                 duration: 0,
-                times: Timing { driving: 0, serving: 0, waiting: 0, break_time: 0 },
+                times: Timing { driving: 0, serving: 0, ..Timing::default() },
             },
             tours: vec![],
             unassigned: Some(vec![UnassignedJob {
