@@ -9,7 +9,7 @@ fn create_test_plan_with_three_jobs() -> Plan {
             create_delivery_job_with_order("job2", vec![5., 0.], 1),
             create_delivery_job("job3", vec![7., 0.]),
         ],
-        relations: Option::None,
+        ..create_empty_plan()
     }
 }
 
@@ -35,7 +35,7 @@ fn can_follow_orders() {
                 cost: 53.,
                 distance: 20,
                 duration: 23,
-                times: Timing { driving: 20, serving: 3, waiting: 0, break_time: 0 },
+                times: Timing { driving: 20, serving: 3, ..Timing::default() },
             },
             tours: vec![Tour {
                 vehicle_id: "my_vehicle_1".to_string(),
@@ -87,7 +87,7 @@ fn can_follow_orders() {
                     cost: 53.,
                     distance: 20,
                     duration: 23,
-                    times: Timing { driving: 20, serving: 3, waiting: 0, break_time: 0 },
+                    times: Timing { driving: 20, serving: 3, ..Timing::default() },
                 },
             }],
             ..create_empty_solution()
