@@ -25,6 +25,7 @@ pub fn create_job(id: &str) -> Job {
         skills: None,
         value: None,
         group: None,
+        compatibility: None,
     }
 }
 
@@ -55,6 +56,18 @@ pub fn create_delivery_job_with_group(id: &str, location: Vec<f64>, group: &str)
     }
 }
 
+pub fn create_delivery_job_with_compatibility(id: &str, location: Vec<f64>, compatibility: &str) -> Job {
+    Job {
+        deliveries: Some(vec![JobTask {
+            places: vec![create_job_place(location, None)],
+            demand: Some(vec![1]),
+            order: None,
+        }]),
+        compatibility: Some(compatibility.to_string()),
+        ..create_job(id)
+    }
+}
+
 pub fn create_delivery_job_with_skills(id: &str, location: Vec<f64>, skills: JobSkills) -> Job {
     Job { skills: Some(skills), ..create_delivery_job(id, location) }
 }
