@@ -31,7 +31,7 @@ fn can_check_load_impl(stop_loads: Vec<i32>, expected_result: Result<(), Vec<Str
                 create_pickup_job("job4", vec![4., 0.]),
                 create_pickup_delivery_job("job5", vec![1., 0.], vec![5., 0.]),
             ],
-            relations: None,
+            ..create_empty_plan()
         },
         fleet: Fleet {
             vehicles: vec![VehicleType {
@@ -63,7 +63,7 @@ fn can_check_load_impl(stop_loads: Vec<i32>, expected_result: Result<(), Vec<Str
             cost: 13.,
             distance: 1,
             duration: 2,
-            times: Timing { driving: 1, serving: 1, waiting: 0, break_time: 0 },
+            times: Timing { driving: 1, serving: 1, ..Timing::default() },
         },
         tours: vec![Tour {
             vehicle_id: "my_vehicle_1".to_string(),
@@ -85,6 +85,7 @@ fn can_check_load_impl(stop_loads: Vec<i32>, expected_result: Result<(), Vec<Str
                         departure: "1970-01-01T00:00:05Z".to_string(),
                     },
                     distance: 1,
+                    parking: None,
                     load: vec![*stop_loads.get(1).unwrap()],
                     activities: vec![
                         Activity {
@@ -93,6 +94,7 @@ fn can_check_load_impl(stop_loads: Vec<i32>, expected_result: Result<(), Vec<Str
                             location: None,
                             time: None,
                             job_tag: None,
+                            commute: None,
                         },
                         Activity {
                             job_id: "job5".to_string(),
@@ -100,6 +102,7 @@ fn can_check_load_impl(stop_loads: Vec<i32>, expected_result: Result<(), Vec<Str
                             location: None,
                             time: None,
                             job_tag: Some("p1".to_string()),
+                            commute: None,
                         },
                     ],
                 },
@@ -110,6 +113,7 @@ fn can_check_load_impl(stop_loads: Vec<i32>, expected_result: Result<(), Vec<Str
                         departure: "1970-01-01T00:00:05Z".to_string(),
                     },
                     distance: 1,
+                    parking: None,
                     load: vec![*stop_loads.get(2).unwrap()],
                     activities: vec![Activity {
                         job_id: "reload".to_string(),
@@ -117,6 +121,7 @@ fn can_check_load_impl(stop_loads: Vec<i32>, expected_result: Result<(), Vec<Str
                         location: None,
                         time: None,
                         job_tag: None,
+                        commute: None,
                     }],
                 },
                 Stop {
@@ -126,6 +131,7 @@ fn can_check_load_impl(stop_loads: Vec<i32>, expected_result: Result<(), Vec<Str
                         departure: "1970-01-01T00:00:08Z".to_string(),
                     },
                     distance: 3,
+                    parking: None,
                     load: vec![*stop_loads.get(3).unwrap()],
                     activities: vec![
                         Activity {
@@ -137,6 +143,7 @@ fn can_check_load_impl(stop_loads: Vec<i32>, expected_result: Result<(), Vec<Str
                                 end: "1970-01-01T00:00:09Z".to_string(),
                             }),
                             job_tag: None,
+                            commute: None,
                         },
                         Activity {
                             job_id: "job3".to_string(),
@@ -147,6 +154,7 @@ fn can_check_load_impl(stop_loads: Vec<i32>, expected_result: Result<(), Vec<Str
                                 end: "1970-01-01T00:00:10Z".to_string(),
                             }),
                             job_tag: None,
+                            commute: None,
                         },
                     ],
                 },
@@ -180,13 +188,14 @@ fn can_check_load_impl(stop_loads: Vec<i32>, expected_result: Result<(), Vec<Str
                 cost: 13.,
                 distance: 1,
                 duration: 2,
-                times: Timing { driving: 1, serving: 1, waiting: 0, break_time: 0 },
+                times: Timing { driving: 1, serving: 1, ..Timing::default() },
             },
         }],
         ..create_empty_solution()
     };
+    let ctx = CheckerContext::new(create_example_problem(), problem, None, solution).unwrap();
 
-    let result = check_vehicle_load(&CheckerContext::new(create_example_problem(), problem, None, solution));
+    let result = check_vehicle_load(&ctx);
 
     assert_eq!(result, expected_result);
 }
@@ -195,7 +204,10 @@ fn can_check_load_impl(stop_loads: Vec<i32>, expected_result: Result<(), Vec<Str
 #[ignore]
 fn can_check_load_when_departure_has_other_activity() {
     let problem = Problem {
-        plan: Plan { jobs: vec![create_pickup_delivery_job("job1", vec![0., 0.], vec![1., 0.])], relations: None },
+        plan: Plan {
+            jobs: vec![create_pickup_delivery_job("job1", vec![0., 0.], vec![1., 0.])],
+            ..create_empty_plan()
+        },
         fleet: Fleet {
             vehicles: vec![create_vehicle_with_capacity("my_vehicle", vec![2])],
             profiles: create_default_matrix_profiles(),
@@ -207,7 +219,7 @@ fn can_check_load_when_departure_has_other_activity() {
             cost: 6.,
             distance: 2,
             duration: 4,
-            times: Timing { driving: 2, serving: 2, waiting: 0, break_time: 0 },
+            times: Timing { driving: 2, serving: 2, ..Timing::default() },
         },
         tours: vec![Tour {
             vehicle_id: "my_vehicle_1".to_string(),
@@ -221,6 +233,7 @@ fn can_check_load_when_departure_has_other_activity() {
                         departure: "1970-01-01T00:00:01Z".to_string(),
                     },
                     distance: 0,
+                    parking: None,
                     load: vec![1],
                     activities: vec![
                         Activity {
@@ -229,6 +242,7 @@ fn can_check_load_when_departure_has_other_activity() {
                             location: None,
                             time: None,
                             job_tag: None,
+                            commute: None,
                         },
                         Activity {
                             job_id: "job1".to_string(),
@@ -236,6 +250,7 @@ fn can_check_load_when_departure_has_other_activity() {
                             location: None,
                             time: None,
                             job_tag: Some("p1".to_string()),
+                            commute: None,
                         },
                     ],
                 },
@@ -261,13 +276,14 @@ fn can_check_load_when_departure_has_other_activity() {
                 cost: 6.,
                 distance: 2,
                 duration: 4,
-                times: Timing { driving: 2, serving: 2, waiting: 0, break_time: 0 },
+                times: Timing { driving: 2, serving: 2, ..Timing::default() },
             },
         }],
         ..create_empty_solution()
     };
+    let ctx = CheckerContext::new(create_example_problem(), problem, None, solution).unwrap();
 
-    let result = check_vehicle_load(&CheckerContext::new(create_example_problem(), problem, None, solution));
+    let result = check_vehicle_load(&ctx);
 
     assert_eq!(result, Ok(()));
 }
